<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="213"/>
        <source>Drop Error</source>
        <translation>Vilkimo klaida</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="214"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Failas/URL &quot;%1&quot; dabar negali būti įtaisytas į spartųjį paleidimą</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="320"/>
        <source>Drop application
icons here</source>
        <translation>Vilkite programų
piktogramas čia</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>Perkelti kairėn</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>Perkelti dešinėn</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>Šalinti iš sparčiojo paleidimo</translation>
    </message>
</context>
</TS>
